deep_learn

Function deep_learn 

pub fn deep_learn(
    training_set: &TrainingSet,
    options: &LearnOptions,
) -> MLResult<DeepLearnOutput>
Analytical nearest-centroid softmax training.

For each class this estimates the class centroid and emits a single dense-softmax classifier with logits equivalent to the linear part of negative squared Euclidean distance plus log-prior:

logit_c(x) = centroid_c dot x - 0.5 * ||centroid_c||^2 + log prior_c.